@@ -4,6 +4,34 @@ without explicit instruction to do so from one of the
 contributers, please do not complain about bugs.
 """
 
+__all__ = [
+    'CODE_PAGES', 'DEFAULT_CLSID', 'FIXED_LENGTH_PROPS',
+    'FIXED_LENGTH_PROPS_STRING', 'HEADER_FORMAT', 'HEADER_FORMAT_TYPE',
+    'HEADER_FORMAT_VALUE_TYPE', 'KNOWN_CLASS_TYPES', 'KNOWN_FILE_FLAGS',
+    'MAINDOC', 'MULTIPLE_16_BYTES', 'MULTIPLE_16_BYTES_HEX',
+    'MULTIPLE_2_BYTES', 'MULTIPLE_2_BYTES_HEX', 'MULTIPLE_4_BYTES',
+    'MULTIPLE_4_BYTES_HEX', 'MULTIPLE_8_BYTES', 'MULTIPLE_8_BYTES_HEX',
+    'NEEDS_ARG', 'NULL_DATE', 'PROPERTIES', 'PSETID_ADDRESS', 'PSETID_AIRSYNC',
+    'PSETID_APPOINTMENT', 'PSETID_ATTACHMENT', 'PSETID_CALENDAR_ASSISTANT',
+    'PSETID_COMMON', 'PSETID_LOG', 'PSETID_MEETING', 'PSETID_MESSAGING',
+    'PSETID_NOTE', 'PSETID_POSTRSS', 'PSETID_SHARING', 'PSETID_TASK',
+    'PSETID_UNIFIEDMESSAGING', 'PSETID_XMLEXTRACTEDENTITIES',
+    'PS_INTERNET_HEADERS', 'PS_MAPI', 'PS_PUBLIC_STRINGS', 'PTYPES',
+    'PYTPFLOATINGTIME_START', 'RE_BIN', 'RE_HTML_BODY_START',
+    'RE_HTML_SAN_SPACE', 'RE_INVALID_FILENAME_CHARACTERS',
+    'RE_INVALID_OLE_PATH', 'RE_RTF_ENC_BODY_START', 'ST1', 'ST2', 'ST3',
+    'STF32', 'STF64', 'STFIX', 'STI16', 'STI32', 'STI64', 'STI8', 'STMF32',
+    'STMF64', 'STMI16', 'STMI32', 'STMI64', 'STNP_ENT', 'STNP_NAM', 'STPEID',
+    'STUI32', 'STVAR', 'ST_BC_FIELD_INFO', 'ST_BC_HEAD', 'ST_BE_F32',
+    'ST_BE_F64', 'ST_BE_I16', 'ST_BE_I32', 'ST_BE_I64', 'ST_BE_I8',
+    'ST_BE_UI16', 'ST_BE_UI32', 'ST_BE_UI64', 'ST_BE_UI8', 'ST_CF_DIR_ENTRY',
+    'ST_DATA_UI16', 'ST_DATA_UI32', 'ST_DATA_UI8', 'ST_GUID', 'ST_LE_F32',
+    'ST_LE_F64', 'ST_LE_I16', 'ST_LE_I32', 'ST_LE_I64', 'ST_LE_I8',
+    'ST_LE_UI16', 'ST_LE_UI32', 'ST_LE_UI64', 'ST_LE_UI8', 'ST_SYSTEMTIME',
+    'ST_TZ', 'VARIABLE_LENGTH_PROPS', 'VARIABLE_LENGTH_PROPS_STRING',
+]
+
+
 import datetime
 import re
 import struct
@@ -31,22 +59,7 @@ RE_HTML_SAN_SPACE = re.compile('  +')
 RE_HTML_BODY_START = re.compile(b'<body[^>]*>')
 # Regular expression to find the start of the html body in encapsulated RTF.
 # This is used for one of the pattern types that makes life easy.
-RE_RTF_ENC_BODY_START_1 = re.compile(br'\{\\\*\\htmltag[0-9]* ?<body[^>]*>\}')
-# Unfortunately, while it would make it easy to find the start of the body in
-# terms of the encapsulated HTML, trying to inject directly into this location
-# has proven to cause some rendering issues that I'll figure out later. For now
-# this is basically the universal start we will try to use.
-RE_RTF_BODY_START = re.compile(br'\\lang[0-9]*')
-# This is an unrelible one to use as it doesn't have a proper way to verify that
-# it will inject in exactly the right place. This is kind of just a "well, let's
-# hope this one works" method.
-RE_RTF_ENC_BODY_UGLY = re.compile(br'<body[^>]*>[^}]*?\}')
-# The following tags are fallbacks that we will try to use, with the higher ones
-# having priority. If we can't find any other way, we try these which should
-# hopefully always work.
-RE_RTF_BODY_FALLBACK_FS = re.compile(br'\\fs[0-9]*[^a-zA-Z]')
-RE_RTF_BODY_FALLBACK_F = re.compile(br'\\f[0-9]*[^a-zA-Z]')
-RE_RTF_FALLBACK_PLAIN = re.compile(br'\\plain[^a-zA-Z0-9]')
+RE_RTF_ENC_BODY_START = re.compile(br'\{\\\*\\htmltag[0-9]* ?<body[^>]*>\}')
 # This is used in the workaround for decoding issues in RTFDE. We find `\bin`
 # sections and try to remove all of them to help with the decoding.
 RE_BIN = re.compile(br'\\bin([0-9]+) ?')
