@@ -1,13 +1,36 @@
 # -*- coding: utf-8 -*-
 
-import logging
-
 """
 extract_msg.exceptions
 ~~~~~~~~~~~~~~~~~~~
 This module contains the set of extract_msg exceptions.
 """
 
+__all__ = [
+    'BadHtmlError',
+    'ConversionError',
+    'DataNotFoundError',
+    'DeencapMalformedData',
+    'DeencapNotEncapsulated',
+    'ExecutableNotFound',
+    'IncompatibleOptionsError',
+    'InvalidFileFormatError',
+    'InvaildPropertyIdError',
+    'InvalidVersionError',
+    'StandardViolationError',
+    'TZError',
+    'UnknownCodepageError',
+    'UnsupportedEncodingError',
+    'UnknownTypeError',
+    'UnsupportedMSGTypeError',
+    'UnrecognizedMSGTypeError',
+    'WKError',
+]
+
+
+import logging
+
+
 # Add logger bus.
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
@@ -17,19 +40,16 @@ class BadHtmlError(ValueError):
     """
     HTML failed to pass validation.
     """
-    pass
 
 class ConversionError(Exception):
     """
     An error occured during type conversion.
     """
-    pass
 
 class DataNotFoundError(Exception):
     """
     Requested stream type was unavailable.
     """
-    pass
 
 class DeencapMalformedData(Exception):
     """
@@ -45,7 +65,6 @@ class ExecutableNotFound(Exception):
     """
     Could not find the specified executable.
     """
-    pass
 
 class IncompatibleOptionsError(Exception):
     """
@@ -56,26 +75,25 @@ class InvalidFileFormatError(OSError):
     """
     An Invalid File Format Error occurred.
     """
-    pass
 
 class InvaildPropertyIdError(Exception):
     """
     The provided property ID was invalid.
     """
-    pass
 
 class InvalidVersionError(Exception):
     """
     The version specified is invalid.
     """
-    pass
 
-class StandardViolationError(Exception):
+class StandardViolationError(InvalidFileFormatError):
     """
     A critical violation of the MSG standards was detected and could not be
     recovered from. Recoverable violations will result in log messages instead.
+
+    Any that could reasonably be skipped, although are likely to still cause 
+    errors down the line, can be suppressed.
     """
-    pass
 
 class TZError(Exception):
     """
@@ -91,13 +109,16 @@ class UnknownCodepageError(Exception):
     """
     The codepage provided was not one we know of.
     """
-    pass
+
+class UnsupportedEncodingError(NotImplementedError):
+    """
+    The codepage provided is known but is not supported.
+    """
 
 class UnknownTypeError(Exception):
     """
     The type specified is not one that is recognized.
     """
-    pass
 
 class UnsupportedMSGTypeError(NotImplementedError):
     """
@@ -110,10 +131,8 @@ class UnrecognizedMSGTypeError(TypeError):
     An exception that is raised when the module cannot determine how to properly
     open a specific class of msg file.
     """
-    pass
 
 class WKError(RuntimeError):
     """
     An error occured while running wkhtmltopdf.
     """
-    pass
