@@ -1,12 +1,11 @@
-import logging
+__all__ = [
+    'Message',
+]
+
 
 from .message_base import MessageBase
 
 
-logger = logging.getLogger(__name__)
-logger.addHandler(logging.NullHandler())
-
-
 # Due to changes to how saving works, Message is now identical to MessageBase,
 # just with a different name. This is for backwards compatability, type
 # identification, and possible future specializations to it.
