@@ -1,3 +1,8 @@
+__all__ = [
+    'MessageBase',
+]
+
+
 import base64
 import datetime
 import email.utils
@@ -16,13 +21,15 @@ import compressed_rtf
 import RTFDE
 
 from email.parser import Parser as EmailParser
-from typing import Callable, Dict, Optional, Tuple, Union
+from typing import Callable, List, Optional, Union
 
 from . import constants
+from ._rtf.create_doc import createDocument
+from ._rtf.inject_rtf import injectStartRTF
 from .enums import DeencapType, RecipientType
 from .exceptions import (
-        DataNotFoundError, DeencapMalformedData, DeencapNotEncapsulated,
-        IncompatibleOptionsError, WKError
+        BadHtmlError, DataNotFoundError, DeencapMalformedData,
+        DeencapNotEncapsulated, IncompatibleOptionsError, WKError
     )
 from .msg import MSGFile
 from .structures.report_tag import ReportTag
@@ -32,6 +39,7 @@ from .utils import (
         inputToBytes, inputToString, isEncapsulatedRtf, prepareFilename,
         rtfSanitizeHtml, rtfSanitizePlain, validateHtml
     )
+
 from imapclient.imapclient import decode_utf7
 
 
@@ -393,7 +401,6 @@ class MessageBase(MSGFile):
         # Log the arguments.
         logger.info(f'Converting to PDF with the following arguments: {processArgs}')
 
-
         # Get the html body *before* calling Popen.
         htmlBody = self.getSaveHtmlBody(**kwargs)
 
@@ -570,53 +577,21 @@ class MessageBase(MSGFile):
             """
             Internal function to replace the body tag with itself plus the header.
             """
-            return bodyMarker.group() + injectableHeader.encode('utf-8')
+            return bodyMarker.group() + injectableHeader
 
-        # Use the previously defined function to inject the RTF header. We are
-        # trying a few different methods to determine where to place the header.
-        data = constants.RE_RTF_BODY_START.sub(replace, self.rtfBody, 1)
-        # If after any method the data does not match the RTF body, then we have
-        # succeeded.
-        if data != self.rtfBody:
-            logger.debug('Successfully injected RTF header using first method.')
-            return data
-
-        # This second method only applies to encapsulated HTML, so we need to check
-        # for that first.
+        # This first method only applies to documents with encapsulated HTML
+        # that is formatted in a nice way.
         if isEncapsulatedRtf(self.rtfBody):
-            data = constants.RE_RTF_ENC_BODY_START_1.sub(replace, self.rtfBody, 1)
+            data = constants.RE_RTF_ENC_BODY_START.sub(replace, self.rtfBody, 1)
             if data != self.rtfBody:
-                logger.debug('Successfully injected RTF header using second method.')
+                logger.debug('Successfully injected RTF header using encapsulation method.')
                 return data
+            logger.debug('RTF has encapsulated HTML, but injection method failed. It is likely dirty. Will use normal RTF injection method.')
 
-            # This third method is a lot less reliable, and actually would just
-            # simply violate the encapuslated html, so for this one we don't even
-            # try to worry about what the html will think about it. If it injects,
-            # we swap to basic and then inject again, more worried about it working
-            # than looking nice inside.
-            if constants.RE_RTF_ENC_BODY_UGLY.sub(replace, self.rtfBody, 1) != self.rtfBody:
-                injectableHeader = constants.RTF_PLAIN_INJECTABLE_HEADER
-                data = constants.RE_RTF_ENC_BODY_UGLY.sub(replace, self.rtfBody, 1)
-                logger.debug('Successfully injected RTF header using third method.')
-                return data
-
-        # Severe fallback attempts.
-        data = constants.RE_RTF_BODY_FALLBACK_FS.sub(replace, self.rtfBody, 1)
-        if data != self.rtfBody:
-            logger.debug('Successfully injected RTF header using forth method.')
-            return data
-
-        data = constants.RE_RTF_BODY_FALLBACK_F.sub(replace, self.rtfBody, 1)
-        if data != self.rtfBody:
-            logger.debug('Successfully injected RTF header using fifth method.')
-            return data
-
-        data = constants.RE_RTF_BODY_FALLBACK_PLAIN.sub(replace, self.rtfBody, 1)
-        if data != self.rtfBody:
-            logger.debug('Successfully injected RTF header using sixth method.')
-            return data
-
-        raise RuntimeError('All injection attempts failed. Please report this to the developer.')
+        # If the normal encapsulated HTML injection fails or it isn't
+        # encapsulated, use the internal _rtf module.
+        logger.debug('Using _rtf module to inject RTF text header.')
+        return createDocument(injectStartRTF(self.rtfBody, injectableHeader))
 
     def save(self, **kwargs):
         """
@@ -901,11 +876,6 @@ class MessageBase(MSGFile):
                         f.write(self.getSaveRtfBody(**kwargs))
                     else:
                         f.write(self.getSaveBody(**kwargs))
-
-        except Exception:
-            if not _zip:
-                self.saveRaw(path)
-            raise
         finally:
             # Close the ZipFile if this function created it.
             if _zip and createdZip:
@@ -1265,7 +1235,7 @@ class MessageBase(MSGFile):
         return self.__recipientSeparator
 
     @property
-    def recipients(self) -> list:
+    def recipients(self) -> List[Recipient]:
         """
         Returns a list of all recipients.
         """
@@ -1306,7 +1276,7 @@ class MessageBase(MSGFile):
             return self._rtfBody
 
     @property
-    def rtfEncapInjectableHeader(self) -> str:
+    def rtfEncapInjectableHeader(self) -> bytes:
         """
         The header that can be formatted and injected into the plain RTF body.
         """
@@ -1315,10 +1285,10 @@ class MessageBase(MSGFile):
         joinStr = r'{\*\htmltag116 <br />}\htmlrtf \line\htmlrtf0 '
         formatter = (lambda name, value : fr'\htmlrtf {{\b\htmlrtf0{{\*\htmltag84 <b>}}{name}: {{\*\htmltag92 </b>}}\htmlrtf \b0\htmlrtf0 {inputToString(rtfSanitizeHtml(value), self.stringEncoding)}\htmlrtf }}\htmlrtf0')
 
-        return self.getInjectableHeader(prefix, joinStr, suffix, formatter)
+        return self.getInjectableHeader(prefix, joinStr, suffix, formatter).encode('utf-8')
 
     @property
-    def rtfPlainInjectableHeader(self) -> str:
+    def rtfPlainInjectableHeader(self) -> bytes:
         """
         The header that can be formatted and injected into the encapsulated RTF
         body.
@@ -1328,7 +1298,7 @@ class MessageBase(MSGFile):
         joinStr = r'\line'
         formatter = (lambda name, value : fr'{{\b {name}: \b0 {inputToString(rtfSanitizePlain(value), self.stringEncoding)}}}')
 
-        return self.getInjectableHeader(prefix, joinStr, suffix, formatter)
+        return self.getInjectableHeader(prefix, joinStr, suffix, formatter).encode('utf-8')
 
     @property
     def sender(self) -> Optional[str]:
