@@ -1,7 +1,25 @@
+from __future__ import annotations
+
 """
 Utility functions of extract_msg.
 """
 
+
+__all__ = [
+    'addNumToDir', 'addNumToZipDir', 'bitwiseAdjust', 'bitwiseAdjustedAnd',
+    'bytesToGuid', 'ceilDiv', 'cloneOleFile', 'createZipOpen',
+    'dictGetCasedKey', 'divide', 'filetimeToDatetime', 'findWk',
+    'fromTimeStamp', 'getCommandArgs', 'getEncodingName', 'getFullClassName',
+    'hasLen', 'htmlSanitize', 'inputToBytes', 'inputToMsgPath', 'inputToString',
+    'isEncapsulatedRtf', 'isEmptyString', 'knownMsgClass', 'filetimeToUtc',
+    'msgPathToString', 'openMsg', 'openMsgBulk', 'parseType', 'prepareFilename',
+    'properHex', 'roundUp', 'rtfSanitizeHtml', 'rtfSanitizePlain',
+    'setupLogging', 'tryGetMimetype', 'unsignedToSignedInt', 'unwrapMsg',
+    'unwrapMultipart', 'validateHtml', 'verifyPropertyId', 'verifyType',
+    'windowsUnicode',
+]
+
+
 import argparse
 import codecs
 import collections
@@ -26,13 +44,22 @@ import olefile
 import tzlocal
 
 from html import escape as htmlEscape
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, TYPE_CHECKING, Union
 
 from . import constants
 from .enums import AttachmentType
-from .exceptions import BadHtmlError, ConversionError, IncompatibleOptionsError, InvalidFileFormatError, InvaildPropertyIdError, TZError, UnknownCodepageError, UnknownTypeError, UnrecognizedMSGTypeError, UnsupportedMSGTypeError
+from .exceptions import (
+        ConversionError, ExecutableNotFound, IncompatibleOptionsError,
+        InvalidFileFormatError, InvaildPropertyIdError, TZError,
+        UnknownCodepageError, UnknownTypeError, UnrecognizedMSGTypeError,
+        UnsupportedEncodingError, UnsupportedMSGTypeError
+    )
 
 
+# Allow for nice type checking.
+if TYPE_CHECKING:
+    from .msg import MSGFile
+
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
 logging.addLevelName(5, 'DEVELOPER')
@@ -261,12 +288,6 @@ def getCommandArgs(args) -> argparse.Namespace:
     # --use-content-id, --cid
     parser.add_argument('--use-content-id', '--cid', dest='cid', action='store_true',
                         help='Save attachments by their Content ID, if they have one. Useful when working with the HTML body.')
-    # --dev
-    parser.add_argument('--dev', dest='dev', action='store_true',
-                        help='Changes to use developer mode. Automatically enables the --verbose flag. Takes precedence over the --validate flag.')
-    # --validate
-    parser.add_argument('--validate', dest='validate', action='store_true',
-                        help='Turns on file validation mode. Turns off regular file output.')
     # --json
     outFormat.add_argument('--json', dest='json', action='store_true',
                         help='Changes to write output files as json.')
@@ -366,7 +387,7 @@ def getCommandArgs(args) -> argparse.Namespace:
     if options.outName and options.noFolders:
         raise IncompatibleOptionsError('--out-name is not compatible with --no-folders.')
 
-    if options.dev or options.fileLogging:
+    if options.fileLogging:
         options.verbose = options.verbose or 1
 
     # Handle the wkOptions if they exist.
@@ -587,7 +608,7 @@ def msgPathToString(inp) -> str:
     return inp
 
 
-def openMsg(path, **kwargs) -> 'MSGFile':
+def openMsg(path, **kwargs) -> MSGFile:
     """
     Function to automatically open an MSG file and detect what type it is.
 
@@ -722,7 +743,7 @@ def openMsg(path, **kwargs) -> 'MSGFile':
         return msg
 
 
-def openMsgBulk(path, **kwargs) -> Union[List['MSGFile'], Tuple[Exception, Union[str, bytes]]]:
+def openMsgBulk(path, **kwargs) -> Union[List[MSGFile], Tuple[Exception, Union[str, bytes]]]:
     """
     Takes the same arguments as openMsg, but opens a collection of msg files
     based on a wild card. Returns a list if successful, otherwise returns a
@@ -792,9 +813,9 @@ def parseType(_type : int, stream, encoding, extras):
             logger.warning(f'Error type found that was not from Additional Error Codes. Value was {value}. You should report this to the developers.')
             # So here, the value should be from Additional Error Codes, but it
             # wasn't. So we are just returning the int. However, we want to see
-            # if it is a normal error type.
+            # if it is a normal error code.
             try:
-                logger.warning(f'REPORT TO DEVELOPERS: Error type of {ErrorType(value)} was found.')
+                logger.warning(f'REPORT TO DEVELOPERS: Error type of {ErrorCode(value)} was found.')
             except ValueError:
                 pass
         return value
@@ -1093,7 +1114,7 @@ def unsignedToSignedInt(uInt : int) -> int:
     return constants.STI32.unpack(constants.STUI32.pack(uInt))[0]
 
 
-def unwrapMsg(msg : 'MSGFile') -> Dict:
+def unwrapMsg(msg : MSGFile) -> Dict:
     """
     Takes a recursive message-attachment structure and unwraps it into a linear
     dictionary for easy iteration. Dictionary contains 4 keys: "attachments" for
